export default {
  name: 'FwAffixTable',
  props: {
    stickyTop: {
      type: Number,
      default: 64
    },
    selector: {
      type: String,
      default: '#scrollContainer'
    }
  },
  data () {
    return {
      scrollContainer: null,
      scrollTop: 0,
      $head: null,
      $body: null,
      ticking: false
    }
  },
  activated () {
    // 如果页面用户keep-alive，列表需要定位到对应项
    if (this.scrollTop && this.scrollContainer) {
      this.scrollContainer.scrollTop = this.scrollTop
      this.scrollContainer.addEventListener('scroll', this.onScroll)
    }
  },
  deactivated () {
    this.scrollContainer.removeEventListener('scroll', this.onScroll)
  },
  beforeDestroy () {
    this.scrollContainer.removeEventListener('scroll', this.onScroll)
  },
  mounted () {
    this.scrollContainer = document.querySelector(this.selector)
    this.$body = this.$el.querySelector('.ant-table-content')
    this.$head = this.$el.querySelectorAll('.ant-table-thead')
    this.setFixedStyle()
    this.scrollContainer.addEventListener('scroll', this.onScroll)
  },
  methods: {
    setFixedStyle () {
      this.$fixedTable = this.$el.querySelectorAll('.ant-table-body .ant-table-thead')
      for (let i = 0; i < this.$fixedTable.length; i++) {
        const item = this.$fixedTable[i]
        item.style.background = 'url(http://about:blank)'
        item.style.backgroundAttachment = 'fixed'
      }
    },
    onScroll () {
      this.scrollTop = this.scrollContainer.scrollTop
      if (!this.ticking) {
        window.requestAnimationFrame(() => {
          const bodyTop = this.$body.getBoundingClientRect().top
          for (let i = 0; i < this.$head.length; i++) {
            const item = this.$head[i]
            if (bodyTop <= this.stickyTop) {
              item.style.transform = `translate3d(0, ${this.stickyTop - bodyTop}px, 0)`
            } else {
              item.style.transform = `translate3d(0, 0, 0)`
            }
            item.style.zIndex = 1
            item.style.position = 'relative'
          }
          this.ticking = false
        })
        this.ticking = true
      }
    }
  },
  render () {
    const props = { ...this.$attrs }
    return (
      <div>
        <a-table style="background-color:white;" props={ props } on={ this.$listeners } scopedSlots={ this.$scopedSlots }>
          { Object.keys(this.$slots).map(name => (<template slot={name}>{this.$slots[name]}</template>)) }
        </a-table>
      </div>
    )
  }
}
